spannertools.GeneralizedBeam
============================

.. abjad-lineage:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam

.. autoclass:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.components
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.durations
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.include_long_duration_notes
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.include_long_duration_rests
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.isolated_nib_direction
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.use_stemlets
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.vertical_direction
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__contains__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__copy__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__eq__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__format__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__getitem__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__hash__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__len__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__lt__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__ne__
      ~abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__repr__

Bases
-----

- :py:class:`spannertools.Spanner <abjad.tools.spannertools.Spanner.Spanner>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject>`

- :py:class:`abctools.AbjadObject.AbstractBase <abjad.tools.abctools.AbjadObject.AbstractBase>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.components
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.durations
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.include_long_duration_notes
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.include_long_duration_rests
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.isolated_nib_direction
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.use_stemlets
   :noindex:

.. autoattribute:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.vertical_direction
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__contains__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__copy__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__eq__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__format__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__getitem__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__hash__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__len__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__lt__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__ne__
   :noindex:

.. automethod:: abjad.tools.spannertools.GeneralizedBeam.GeneralizedBeam.__repr__
   :noindex:
